/**
 * # CHAPTER #
 * ============================================================================
 * MUSASHIで必要な全てのヘッダーをinclueするためのヘッダーファイル
 * ============================================================================
 */


#ifndef __MUSASHI_H
#define __MUSASHI_H 1

#include <musashi/mssConfig.h>
#include <musashi/mssBase.h>
#include <musashi/mssUniq.h>
#include <musashi/mssAgg.h>
#include <musashi/mssInput.h>
#include <musashi/mssOutput.h>
#include <musashi/mssXtTag.h>
#include <musashi/mssOption.h>
#include <musashi/mssHeader.h>
#include <musashi/mssCal.h>
#include <musashi/mssHash.h>
#include <musashi/mssXml.h>
#include <musashi/mssValue.h>
#include <musashi/mssPMML.h>
#include <musashi/mssMisc.h>
#include <musashi/qs5.h>
#include <musashi/random.h>

#endif
